@@ -23,6 +23,7 @@ from rare.models.game import RareGame
 from rare.models.pathspec import PathSpec
 from rare.models.settings import RareAppSettings, app_settings
 from rare.shared import RareCore
+from rare.shared.workers.cloud_sync import CloudSyncWorker
 from rare.shared.workers.wine_resolver import WineSavePathResolver
 from rare.ui.components.tabs.library.details.cloud_settings_widget import (
     Ui_CloudSettingsWidget,
@@ -34,12 +35,11 @@ from rare.widgets.indicator_edit import IndicatorReasonsCommon, PathEdit
 from rare.widgets.loading_widget import LoadingWidget
 from rare.widgets.side_tab import SideTabContents
 
-logger = getLogger("CloudSaves")
-
 
 class CloudSaves(QWidget, SideTabContents):
     def __init__(self, settings: RareAppSettings, rcore: RareCore, parent=None):
         super(CloudSaves, self).__init__(parent=parent)
+        self.logger = getLogger(type(self).__name__)
 
         self.sync_widget = QWidget(self)
         self.sync_ui = Ui_CloudSyncWidget()
@@ -115,22 +115,24 @@ class CloudSaves(QWidget, SideTabContents):
     def upload(self):
         self.sync_widget.setEnabled(False)
         self.loading_widget.setVisible(True)
-        self.rgame.upload_saves()
+        worker = CloudSyncWorker(self.rgame, CloudSyncWorker.Mode.UPLOAD)
+        self.rcore.enqueue_worker(self.rgame, worker)
 
     def download(self):
         self.sync_widget.setEnabled(False)
         self.loading_widget.setVisible(True)
-        self.rgame.download_saves()
+        worker = CloudSyncWorker(self.rgame, CloudSyncWorker.Mode.DOWNLOAD)
+        self.rcore.enqueue_worker(self.rgame, worker)
 
     def __compute_save_path(self):
         if self.rgame.is_installed and self.rgame.game.supports_cloud_saves:
             try:
-                with timelogger(logger, "Detecting save path"):
+                with timelogger(self.logger, "Detecting save path"):
                     new_path = self.core.get_save_path(self.rgame.app_name)
                 if platform.system() != "Windows" and not os.path.exists(new_path):
                     raise ValueError(f'Path "{new_path}" does not exist.')
             except Exception as e:
-                logger.warning(str(e))
+                self.logger.warning(str(e))
                 resolver = WineSavePathResolver(self.core, self.rgame)
                 # if not resolver.environ.get("WINEPREFIX"):
                 #     del resolver
@@ -153,8 +155,8 @@ class CloudSaves(QWidget, SideTabContents):
 
     @Slot(str, str)
     def __on_wine_resolver_result(self, path, app_name):
-        logger.info("Wine resolver finished for %s", app_name)
-        logger.info("Computed save path: %s", path)
+        self.logger.info("Wine resolver finished for %s", app_name)
+        self.logger.info("Computed save path: %s", path)
         if app_name == self.rgame.app_name:
             self.cloud_save_path_edit.setDisabled(False)
             self.compute_save_path_button.setDisabled(False)
@@ -213,7 +215,7 @@ class CloudSaves(QWidget, SideTabContents):
             RareGame.State.RUNNING,
             RareGame.State.SYNCING,
         ]
-        self.sync_widget.setDisabled(button_disabled)
+        self.sync_widget.setDisabled(button_disabled or not self.rgame.is_idle)
         if self.rgame.state == RareGame.State.SYNCING:
             self.loading_widget.start()
         else:
