@@ -1,5 +1,5 @@
 from PySide6.QtCore import Qt
-from PySide6.QtWidgets import QTreeView, QDialog, QVBoxLayout
+from PySide6.QtWidgets import QDialog, QTreeView, QVBoxLayout
 
 from rare.utils.json_formatter import QJsonModel
 
@@ -14,7 +14,7 @@ class DebugView(QTreeView):
         self.setContextMenuPolicy(Qt.ContextMenuPolicy.ActionsContextMenu)
         try:
             self.model.load(data)
-        except Exception as e:
+        except Exception:
             pass
         self.resizeColumnToContents(0)
 
